import pytest
from pathlib import Path
import glob
from chess_insight.game import Game


test_data_path = Path(__file__).parent / "test_data"


class TestGame:
    @pytest.mark.parametrize("pgn_path", glob.glob(str(test_data_path / "*.pgn")))
    def test_game(self, pgn_path):
        usr = self._get_usr(pgn_path)
        with open(pgn_path, "r") as f:
            game = Game(f.read(), usr)
        parsed_game = game.asdict()
        assert None not in parsed_game.values()

    def _get_usr(self, pgn_path: str):
        return Path(pgn_path).stem.split("_")[0]



import io

import chess.pgn
from typing import Literal
from enum import IntEnum, Enum
from pathlib import Path
import os
import json


class Color(IntEnum):
    WHITE = 1
    BLACK = 0


class GamePhase(Enum):
    OPENING = "opening"
    MIDDLE_GAME = "middle_game"
    END_GAME = "end_game"


class Mistakes(IntEnum):
    INACCURACY = 50
    MISTAKE = 120
    BLUNDER = 200


class ResultReason(IntEnum):
    INSUFFICIENT_MATERIAL = 4
    REPETITION = 3
    RESIGN = 2
    TIMEOUT = 1
    MATE = 0


class Result(Enum):
    WHITE = "1-0"
    BLACK = "0-1"
    DRAW = "1/2-1/2"
    ON_GOING = "*"


def get_pgn(pgn: str) -> chess.pgn.Game:
    """extracts a pgn file."""
    pgn = io.StringIO(pgn)
    game = chess.pgn.read_game(pgn)
    return game


def get_time_class(
    pgn: chess.pgn.Game,
) -> Literal["bullet", "blitz", "rapid", "classical"]:
    time_control = pgn.headers["TimeControl"]
    time_control = time_control.split("/")[-1]  # daily time control
    if time_control.count("+") > 1:
        raise ValueError(f'Invalid time control: {pgn.headers["TimeControl"]}')
    time = int(time_control.split("+")[0])
    if time < 180:
        return "bullet"
    if time < 600:
        return "blitz"
    if time < 1800:
        return "rapid"
    return "classical"


def load_eco() -> list[str]:
    with open(
        os.path.join(Path(__file__).parent / "data" / Path("openings.json")),
        encoding="utf-8",
    ) as f:
        eco = json.load(f)
    return eco



import json
import os
from abc import ABC
from logging import Logger
from pathlib import Path
from typing import Generator
from abc import abstractmethod
import requests
from stockfish import Stockfish
from easy_logs import get_logger
from chess_insight.game import Game
from rich.progress import track
from rich.status import Status

logger = get_logger()


class ApiCommunicator(ABC):
    HOST: str = None

    def __init__(self, stockfish_path: Path = "stockfish.exe", depth: int = 10) -> None:
        """
        Summary:
            Abstract class for API communication. It is used to get games from chess.com, lichess, etc.
            Each subclass should implement get_games method.
        Args:
            logger (Logger): logger to log to
            depth (int, optional): depth of stockfish engine. Defaults to 10.
        """
        if not stockfish_path or not Path(stockfish_path).exists():
            logger.warning(
                f"Stockfish does not exists in given path {stockfish_path}. Therefore won't be used."
            )
            self.stockfish = None
            return
        try:
            stockfish_path = Path(stockfish_path).resolve()
            self.stockfish = Stockfish(stockfish_path.resolve(), depth=depth)
        except (AttributeError, FileNotFoundError) as err:
            raise err

    def split_pgns(self, text_pgn: str) -> list[str]:
        """
        Summary:
            Splits pgn string into list of pgn strings.
        Args:
            text_pgn (str): pgn string to split
        Returns:
            list of pgn strings
        """
        pgns = text_pgn.split("\n\n\n")
        while pgns and len(pgns[-1]) == 0:
            pgns.pop()
        return pgns

    def games_generator(
        self, username: str, count: int, time_class: str
    ) -> Generator[Game, None, None]:
        """
        Args:
            username (str): username on given portal (lichess, chess.com, etc.) to get games from
            list_of_pgns (int): number of pgn strings to compute
        returns:
            generator of Game objects, each representing a game played on chess.com
        """
        status = Status(f"Collecting {count} pgns from {self.HOST}\n")
        status.start()
        list_of_pgns = self.get_pgns(username, count, time_class)
        status.stop()
        logger.info(f"Collected {len(list_of_pgns)} games")
        progress = track(
            list_of_pgns,
            description=f"Analyzing games for {username}\n",
            total=len(list_of_pgns),
            transient=True,
        )
        for game in progress:
            game = Game(
                game,
                username,
                stockfish=self.stockfish,
            )
            yield game

    @abstractmethod
    def get_pgns(
        self, username: str, number_of_games: int, time_class: str
    ) -> Generator[Game, None, None]:
        """
        Args:
            username (str): username on given portal (lichess, chess.com, etc.) to get games from
            games (int): number of lastest games to get
            time_class (_type_): time class of games to get (blitz, rapid, bullet, daily)
        returns:
            generator of Game objects, each representing a game played on chess.com, licess, etc.
        """



from typing import Literal
from rich.console import Console
from rich.markdown import Markdown
from chess_insight import (
    ChessComApiCommunicator,
    LichessApiCommunicator,
    export_games_to_csv,
    export_games_to_json,
)
from pydantic import BaseModel, Field, NonNegativeInt, ValidationError
from pathlib import Path

STOCKFISH_PATH = Path(__file__).parent.parent / "stockfish.exe"


class HostSpecific(BaseModel):
    username: str = Field(
        None,
        help="Provide username (leave blank to skip)",
    )
    games_to_download: NonNegativeInt = Field(
        help="Provide number of games to download ", default=10
    )

    def __hash__(self):  # make hashable BaseModel subclass
        return hash((type(self),) + tuple(self.__dict__.values()))

    class Config:
        validate_assignment = True


class GenericQueries(BaseModel):
    time_control: Literal["bullet", "blitz", "rapid", "classical"] = Field(
        help="Provide time control (`bullet`, `blitz`, `rapid`, `classical`)",
        default="blitz",
    )
    file_format: Literal["json", "csv"] = Field(
        help="Provide file format for exported data (`csv`, `json`)", default="csv"
    )
    file_name: str = Field(help="Provide file name for exported data", default="games")
    engine_depth: NonNegativeInt = Field(
        help="Provide engine depth for analysis", default=10
    )

    class Config:
        validate_assignment = True


WELCOME_MESSAGE = f"""
# **Welcome to chess_insight interactive mode!**

### Github page: `https://github.com/michalskibinski109/chess_insight`
### PyPI page: `https://pypi.org/project/chess_insight/`
### Author: `michalskibinski109@gmail.com`

# *Have fun!*
"""


def input_model_data(console, model: BaseModel) -> BaseModel:
    for name, query in model.model_json_schema()["properties"].items():
        while True:
            answer = console.input(f"{query['help']} default `{query['default']}`: ")
            if name == "username" and answer == "":
                return None
            if answer == "":
                break
            try:
                model.__setattr__(name, answer)
                break
            except ValidationError as e:
                console.print(e.errors()[0]["msg"])
                console.print("Try again!")
    return model


def main():
    console = Console()
    md = Markdown(WELCOME_MESSAGE)
    console.print(md)
    console.print("General questions:", style="bold green ", justify="center")
    general: GenericQueries = input_model_data(console, GenericQueries())
    console.print("lichess.org specific:", style="bold blue", justify="center")
    lichess: HostSpecific = input_model_data(console, HostSpecific())
    console.print("chess.com specific:", style="bold blue", justify="center")
    chess_com: HostSpecific = input_model_data(console, HostSpecific())
    console.print(general, lichess, chess_com)
    HOSTS = {
        chess_com: ChessComApiCommunicator(STOCKFISH_PATH, depth=general.engine_depth),
        lichess: LichessApiCommunicator(STOCKFISH_PATH, depth=general.engine_depth),
    }
    console.print("Downloading games...")
    games = []
    for config, communicator in HOSTS.items():
        if not config:
            continue
        games += list(
            communicator.games_generator(
                config.username,
                config.games_to_download,
                general.time_control,
            )
        )
    console.print("Games downloaded!")
    if general.file_format == "csv":
        df = export_games_to_csv(games, f"{general.file_name}.csv")
        console.print("Games exported to {general.file_name}.csv!")
        console.print(df.head())
    else:
        export_games_to_json(games, f"{general.file_name}.json")
        console.print("Games exported to {general.file_name}.json!")
        console.print(games[0].asdict())


if __name__ == "__main__":
    main()



from chess_insight.api_communicator import ApiCommunicator
import chessdotcom
from chessdotcom.types import ChessDotComError
from easy_logs import get_logger
from datetime import datetime
from chess_insight.utils import get_time_class, get_pgn

logger = get_logger()


class ChessComApiCommunicator(ApiCommunicator):
    HOST = "chess.com"

    def _get_joined_year(self, usr: str) -> int:
        if not usr:
            logger.error("No username provided")
            return []
        try:
            user = chessdotcom.get_player_profile(usr).json
        except ChessDotComError as err:
            logger.error(f"Failed to get user {usr} from {self.HOST}: {err.text}")
            raise err
        joined = user["player"]["joined"]
        year = datetime.fromtimestamp(joined).year
        logger.debug(f"User {usr} joined in year: {year}")
        return year

    def get_pgns(self, username: str, count: int, time_class: str) -> list[str]:
        joined_year = self._get_joined_year(username)
        games = []
        for y in range(datetime.now().year, joined_year - 1, -1):
            month = int(datetime.now().month) if y == datetime.now().year else 12
            for m in range(month, 0, -1):
                logger.debug(f"Downloading games from {y}-{m}")
                games_list = chessdotcom.get_player_games_by_month_pgn(username, y, m)
                games_list = self.split_pgns(games_list.json["pgn"]["pgn"])
                for g in games_list:
                    if len(games) >= count:
                        return games
                    if get_time_class(get_pgn(g)) == time_class and not (
                        get_pgn(g).headers.get("variant")
                    ):
                        games.append(g)
        logger.warning(
            f"User {username} played only {len(games)} games on {self.HOST}."
        )
        return games


if __name__ == "__main__":
    lichess = ChessComApiCommunicator()
    from rich import print
    from pprint import pprint
    from pathlib import Path

    tests_path = Path(__file__).parent.parent / "tests" / "test_data"
    games = lichess.games_generator("barabasz60", 5, "blitz")
    list_of_games = list(games)
    # for i, game in enumerate(games):
    #     with open(tests_path / f"barabasz60_chess_com_{i}.pgn", "w") as f:
    #         f.write(game)



import chess.pgn
from easy_logs import get_logger
from chess_insight.utils import (
    load_eco,
    Color,
    GamePhase,
    Result,
    ResultReason,
    get_pgn,
    get_time_class,
)
from typing import Literal, Annotated
from stockfish import Stockfish
from datetime import datetime
from chess_insight.semi_dataclass import SemiDataclass
from chess_insight.player import Player
from functools import cached_property
from urllib.parse import urlparse
import io


logger = get_logger()


class Game(SemiDataclass):
    _ECO = load_eco()

    _PIECE_ENDGAME_VALUES = {
        "p": 1,
        "P": 1,
        "n": 3,
        "N": 3,
        "q": 8,
        "Q": 8,
        "r": 4,
        "R": 4,
        "b": 3,
        "B": 3,
        "k": 0,
        "K": 0,
    }

    host: Annotated[str, "Server where game was played."]

    username: Annotated[str, "Username of player."]

    time_class: Annotated[
        Literal["bullet", "blitz", "rapid", "classical"], "Time class of game."
    ]

    opening: Annotated[str | None, "Opening name in ECO format."]

    player: Annotated[Player, "Dict containing player data. Determined by `username`."]

    opponent: Annotated[Player, "Dict containing opponent data."]

    url: Annotated[str, "Url to game."]

    def __init__(self, pgn_string: str, usr: str, stockfish: Stockfish = None) -> None:
        self._pgn = get_pgn(pgn_string)
        self._board = chess.pgn.read_game(
            io.StringIO(pgn_string), Visitor=chess.pgn.BoardBuilder
        )
        self.username = usr
        self.time_class = get_time_class(self._pgn)
        self._evaluations = self._get_evaluations(stockfish)
        self.opening, self._opening_end = self._set_opening()
        self.player = Player(
            self._pgn,
            self._board,
            self.player_color,
            self.phases,
            evaluations=self._evaluations,
        )

        self.opponent = Player(
            self._pgn,
            self._board,
            not self.player_color,
            self.phases,
            evaluations=self._evaluations,
        )

    def _get_evaluations(self, stockfish: Stockfish | None) -> list:
        evaluations = []
        total, add_time = map(float, self.time_control.split("+"))
        white_time = black_time = total
        evaluation = 0
        if stockfish:
            stockfish.set_position()
        for move in self._pgn.mainline():
            if stockfish:
                stockfish.make_moves_from_current_position([move.uci()])
                evaluation = stockfish.get_evaluation()
                if evaluation["type"] == "mate":
                    evaluation = evaluation["value"] * 1000
                else:
                    evaluation = evaluation["value"]
            if abs(evaluation) > 1000:
                evaluation = (evaluation / abs(evaluation)) * 1000  # normalize
            if move.turn() == Color.WHITE.value:  # time is added after white move
                time = round((white_time - move.clock()) + add_time, 2)
                white_time = move.clock()
            else:
                time = round((black_time - move.clock()) + add_time, 2)
                black_time = move.clock()
            evaluations.append({"evaluation": evaluation, "time": time})
        return evaluations

    @property
    def host(self) -> str:
        """
        Server where game was played.
        """
        site = urlparse(self._pgn.headers.get("Site"))
        if not site.hostname:
            site = urlparse(self._pgn.headers.get("Link"))
        if not site.hostname:
            raise ValueError(f"Invalid url: {self._pgn.headers.get('Site')}")
        return site.hostname.lower().split("www.")[-1]

    @property
    def url(self) -> str:
        """
        Url to game.
        """
        match self.host:
            case "lichess.org":
                return self._pgn.headers.get("Site")
            case "chess.com":
                return self._pgn.headers.get("Link")
            case _:
                raise ValueError(f"Unknown host: {self.host}")

    @property
    def player_color(self) -> Color:
        """
        Player color in game.
        """
        if self.username.lower() in self._pgn.headers["White"].lower():
            return Color.WHITE
        if self.username.lower() in self._pgn.headers["Black"].lower():
            return Color.BLACK
        raise ValueError(f"Pgn: {self._pgn} \nUsername: {self.username}")

    @property
    def time_control(self) -> str:
        """
        time control in format "time+increment" in seconds.
        e.g. "600+0" or "180+2"
        """
        time_control = self._pgn.headers["TimeControl"].split("/")[-1]
        if "+" not in time_control:
            time_control = time_control + "+0"
        if time_control.count("+") != 1:
            raise ValueError("Invalid timeControl: " + self._pgn.headers["TimeControl"])
        return time_control

    @property
    def date(self) -> datetime:
        """
        Date and time of game in UTC.
        """
        date = self._pgn.headers["UTCDate"]
        time = self._pgn.headers["UTCTime"]
        date_time = datetime.strptime(date + " " + time, "%Y.%m.%d %H:%M:%S")
        return date_time

    @property
    def end_reason(self) -> str:
        """
        Reason of game end.
        """
        comment = self._pgn.end().comment.lower()
        if not comment or comment.startswith("[%clk") and comment.endswith("]"):
            comment = self._pgn.headers.get("Termination").lower()
        if "repetition" in comment:
            return ResultReason.REPETITION
        if "insufficient" in comment:
            return ResultReason.INSUFFICIENT_MATERIAL
        if "resigns" in comment or "resignation" in comment or "abandoned" in comment:
            return ResultReason.RESIGN
        elif (
            "wins on time" in comment
            or "won on time" in comment
            or "time forfeit" in comment
        ):
            return ResultReason.TIMEOUT
        elif "checkmate" in comment:
            return ResultReason.MATE
        else:
            logger.warning(f"Unknown result reason: {comment}")
        return "unknown"

    @property
    def result(self) -> Result:
        """
        Result of game. Black, White or Draw.
        """
        res = Result(self._pgn.headers["Result"])

        return res

    def _set_opening(self) -> tuple[str | None, int]:
        """
        Opening name in ECO format.
        Improtant: This method has side effect!!! It sets `self._opening_end`
        """
        board = self._board.copy()
        for _ in range(len(board.move_stack) - len(self._ECO)):
            board.pop()
        for i in range(len(board.move_stack) - 1, -1, -1):
            for opening in self._ECO[i]:
                if opening["fen"] in board.fen():
                    return opening["name"], len(board.move_stack)
            board.pop()
        logger.warning(f"There is no opening in game played {self.date}")
        self._opening_end = 0
        return None, 0

    @property
    def opening_short(self) -> str:
        """
        Short opening name in ECO format.
        e.g. "Sicilian Defense: Alapin Variation" -> "Sicilian Defense"
        """
        return self.opening.split(":")[0]

    @cached_property
    def phases(self) -> dict:
        """
        Phases in half moves
        https://en.wikipedia.org/wiki/Chess_endgame#The_start_of_the_endgame
        """
        game = self._board.copy()
        if self._opening_end == -1:
            raise ValueError("You have to call `self.opening` first")
        board = chess.Board()
        middle_game_end = len(game.move_stack)
        for index, move in enumerate(game.move_stack):
            board.push(move)
            points = sum(
                self._PIECE_ENDGAME_VALUES[str(i)] for i in board.piece_map().values()
            )
            if points < 27:  # if more it is endgame
                middle_game_end = max(index, self._opening_end)
                break
        return {
            GamePhase.OPENING: self._opening_end,
            GamePhase.MIDDLE_GAME: middle_game_end,
            GamePhase.END_GAME: (len(game.move_stack)),
        }


if __name__ == "__main__":
    with open("tests/test_data/barabasz60_chess_com_0.pgn") as f:
        pgn = f.read()
    game = Game(pgn, "barabasz60", Stockfish("stockfish.exe", depth=4))
    from rich import inspect, print

    print(game.render_docs())
    print(game.player.render_docs())
    print(game.asdict())



from __future__ import annotations
from abc import ABC
from enum import Enum
from rich.console import Console
from rich.markdown import Markdown
from typing import get_type_hints
from collections.abc import MutableMapping
from easy_logs import get_logger

logger = get_logger()


class SemiDataclass(ABC):
    _ROUND_TO = 4

    def print_md(self) -> None:
        """
        Prints markdown documentation of class.
        """

        console = Console()
        md = Markdown(self.render_docs())
        console.print(md)

    def render_docs(self) -> str:
        docs_content = "### " + self.__class__.__name__ + " object\n\n"
        table_data = []
        for name, value in vars(self.__class__).items():
            if not name.startswith("_"):  # Exclude special attributes
                docstring = (
                    getattr(value, "__doc__", "NO DOCSTRING").strip().replace("\n", " ")
                )
                value = getattr(self, name)
                table_data.append([name, docstring, value])

        annotated_hints = get_type_hints(self.__class__, include_extras=True)
        for name, hint in annotated_hints.items():
            docstring = hint.__metadata__[0]
            value = getattr(self, name)
            table_data.append([name, docstring, value])

        docs_content += "| Attribute | Description  |\n"
        docs_content += "| --- | --- | \n"
        for row in table_data:
            docs_content += f"| `{row[0]}` | {row[1]}  |\n"

        return docs_content

    def _convert_enum_values(self, obj):
        if isinstance(obj, SemiDataclass):
            return obj.asdict()
        if isinstance(obj, Enum):
            return obj.name.lower()
        if isinstance(obj, float):
            return round(obj, self._ROUND_TO)
        elif isinstance(obj, dict):
            return {
                self._convert_enum_values(k): self._convert_enum_values(v)
                for k, v in obj.items()
            }
        elif isinstance(obj, list) or isinstance(obj, tuple):
            return [self._convert_enum_values(item) for item in obj]
        else:
            return obj

    def _flatten_dict(cls, dictionary: dict, parent_key="", separator="_"):
        items = []
        for key, value in dictionary.items():
            new_key = parent_key + separator + key if parent_key else key
            if isinstance(value, MutableMapping):
                items.extend(
                    cls._flatten_dict(value, new_key, separator=separator).items()
                )
            else:
                items.append((new_key, value))
        return dict(items)

    def flatten(self) -> dict:
        dict_data = self.asdict()
        return self._flatten_dict(dict_data)

    def asdict(self) -> dict:
        """
        Returns class represented as dict. Changes enum classes to its values.
        """
        game_dict = {}
        for attr_name in dir(self):
            attr = getattr(self, attr_name)
            if not attr_name.startswith("_") and not callable(attr):
                # Convert Enum members to their values
                attr = self._convert_enum_values(attr)
                game_dict[attr_name] = attr
        return game_dict



from chess_insight.chess_com_api_communicator import ChessComApiCommunicator
from chess_insight.lichess_api_communicator import LichessApiCommunicator
from chess_insight.api_communicator import ApiCommunicator
from chess_insight.game import Game
import pandas as pd
from easy_logs import get_logger
from pathlib import Path

logger = get_logger()


def get_communicator(
    host: str, engine_depth: int = None, engine_path: Path = None
) -> ApiCommunicator:
    HOSTS = {
        "chess.com": ChessComApiCommunicator(engine_path, depth=engine_depth),
        "lichess.org": LichessApiCommunicator(engine_path, depth=engine_depth),
    }
    return HOSTS[host]


def export_games_to_csv(games: list, file_name: str = "games.csv") -> pd.DataFrame:
    logger.debug(f"Saving {len(games)} games to {file_name}")
    json_data = [game.flatten() for game in games]
    df = pd.DataFrame(json_data)
    df.to_csv(file_name, index=False)
    logger.info(f"Saved {len(games)} games to {file_name}")
    return df


def export_games_to_json(games: list, file_name: str = "games.json"):
    logger.info(f"Saving {len(games)} games to {file_name}")
    json_data = [game.asdict() for game in games]
    df = pd.DataFrame(json_data)
    df.to_json(file_name, index=False)
    logger.info(f"Saved {len(games)} games to {file_name}")



from easy_logs import get_logger
from chess_insight.semi_dataclass import SemiDataclass
from chess_insight.utils import Color, GamePhase, Mistakes
import chess.pgn
from collections import defaultdict
from statistics import mean

logger = get_logger()


class Player(SemiDataclass):
    def __init__(
        self,
        pgn: chess.pgn.Game,
        board: chess.Board,
        color: Color,
        game_phases: tuple,
        evaluations: list,
    ) -> None:
        self._pgn = pgn
        self._board = board
        self._color = color
        self._phases = game_phases
        self._evaluations = (
            evaluations  # [{'evaluation': float, 'time': float},] only for given color
        )

    @property
    def elo(self) -> int:
        """
        elo of player at the time of game.
        """
        prop_name = {
            Color.WHITE: "WhiteElo",
            Color.BLACK: "BlackElo",
        }
        return int(self._pgn.headers[prop_name[self._color]])

    @property
    def avg_move_time(self) -> dict:
        """
        list with average move time for each phase.
        """
        data = {}
        if len(self._evaluations) < 3:
            return {}
        idx = 0 if self._color == Color.WHITE else 1
        times = [item["time"] for item in self._evaluations]
        for phase in GamePhase:
            vals = times[idx : self._phases[phase] : 2]
            data[phase] = mean(vals) if vals else 0
        return data

    @property
    def evaluation(self) -> dict:
        """
        dict with number of mistakes for each phase.
        """
        idx = 0 if self._color == Color.WHITE else 1
        mul = 1 if self._color == Color.WHITE else -1
        mist = [item["evaluation"] for item in self._evaluations]
        last_eval = last_idx = 0  # we need to track last eval from phase before
        data = defaultdict(dict)
        for phase in GamePhase:  # intEnum
            evals = [last_eval] + mist[
                last_idx : self._phases[phase]
            ]  # get all moves from given phase
            last_idx = self._phases[phase]
            for mistake_type in Mistakes:
                data[phase][mistake_type] = sum(
                    (mul * mistake_type.value < evals[i - 1] - evals[i])
                    for i in range(idx, len(evals) // 2, 2)
                )
        return data



from chess_insight.api_communicator import ApiCommunicator
from typing import Generator
import berserk
from easy_logs import get_logger
import os

logger = get_logger()


class LichessApiCommunicator(ApiCommunicator):
    HOST = "lichess.org"
    CLIENT = berserk.Client()

    def get_pgns(self, username: str, count: int, time_class: str) -> list[str]:
        games = self.CLIENT.games.export_by_player(
            username, max=count, perf_type=time_class, as_pgn=True, clocks=True
        )

        try:
            list_of_games = list(games)
        except berserk.exceptions.ResponseError as err:
            logger.error(f"Failed to get games from {self.HOST}: {err}")
            if err.status_code == 404:
                logger.error(f"User {username} doesn't exist on {self.HOST}.")
            raise err
        if len(list_of_games) < count:
            logger.warning(
                f"User {username} played only {len(list_of_games)} games on {self.HOST}."
            )
        return list_of_games


if __name__ == "__main__":
    lichess = LichessApiCommunicator()

    from pathlib import Path

    tests_path = Path(__file__).parent.parent / "tests" / "test_data"
    games = lichess.games_generator("pro100wdupe", 20, "blitz")
    for game in games:
        game.asdict()
    # for i, game in enumerate(games):
    #     with open(tests_path / f"pro100wdupe_lichess_{i}.pgn", "w") as f:
    #         f.write(game)

    # pprint(list(lichess.get_games("Pro100wdupe", 1, "rapid")))
    # valid = lichess.get_valid_username("michal")
    # pprint(valid)



from pathlib import Path

import setuptools

__version__ = "0.3.0"
__author__ = "Michał Skibiński"

this_directory = Path(__file__).parent

with open(this_directory / "requirements.txt") as f:
    requirements = f.read().splitlines()

with open(this_directory / "README.md") as f:
    readme = f.read()


setuptools.setup(
    name="chess_insight",
    install_requires=requirements,
    version=__version__,
    author=__author__,
    author_email="mskibinski109@gmail.com",
    description="""
        Modern package for analyzing chess games. 
        """.replace(
        "\n", " "
    ).strip(),
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    # chess_insight/openings.json
    package_data={"chess_insight": ["data/openings.json", "data/*"]},
    license="GPL-3.0+",
    keywords=" chess, statistic, game, board",
    url="https://github.com/michalskibinski109/chess_insight",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Games/Entertainment :: Board Games",
        "Topic :: Games/Entertainment :: Turn Based Strategy",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Typing :: Typed",
    ],
    python_requires=">=3.10",
)
